==> ejc-sealm-impl-3.0.0-20220707.102343-98-sources.jar: com/ejianc/business/sealm/bean/G9dzhtEntity.java <==
package com.ejianc.business.sealm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * G9历史工程电子合同
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_g9dzht")
public class G9dzhtEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="htlx_id")
    private Long htlxId; // 合同类型id
    @TableField(value="htlx_name")
    private String htlxName; // 合同类型名称
    @TableField(value="sq_date")
    private Date sqDate; // 申请日期
    @TableField(value="ht_code")
    private String htCode; // 合同编号
    @TableField(value="ht_name")
    private String htName; // 合同名称
    @TableField(value="htje")
    private BigDecimal htje; // 合同金额
    @TableField(value="babh_id")
    private Long babhId; // 备案编号id
    @TableField(value="babh_name")
    private String babhName; // 备案编号名称
    @TableField(value="htfs")
    private Integer htfs; // 合同份数（默认1）
    @TableField(value="jbr_id")
    private Long jbrId; // 经办人id
    @TableField(value="jbr_name")
    private String jbrName; // 经办人名称
    @TableField(value="jbr_tel")
    private String jbrTel; // 经办人联系方式
    @TableField(value="supplier")
    private String supplier; // 供方
    @TableField(value="sp_user")
    private String spUser; // 供方经办人
    @TableField(value="sp_tel")
    private String spTel; // 供方电话

    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="begin_date")
    private Date beginDate; // 开始日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称

    @TableField(value="sign_type")
    private Integer signType; // 0双方签署，1单方签署

    @TableField(value="htlb")
    private Integer htlb; // 合同类别 0正式，1补充协议
    @TableField(value="ht_id")
    private Long htId; // 合同编号id
    @TableField(value="attachment_file_id")
    private Long attachmentFileId; // 签章文件id
    @TableField(value="attachment_file_name")
    private String attachmentFileName; // 签章文件名称


    @TableField(value="signature_status")
    private String signatureStatus; // 签章状态（1表示已签章）
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别
    @TableField(value="signed_file_id")
    private Long signedFileId; // 签章完成文件


    public Long getSignedFileId() {
        return signedFileId;
    }

    public void setSignedFileId(Long signedFileId) {
        this.signedFileId = signedFileId;
    }

    public Long getYzlbId() {
        return yzlbId;
    }

    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }

    public String getYzlbName() {
        return yzlbName;
    }

    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getHtlxId() {
        return htlxId;
    }

    public void setHtlxId(Long htlxId) {
        this.htlxId = htlxId;
    }
    public String getHtlxName() {
        return htlxName;
    }

    public void setHtlxName(String htlxName) {
        this.htlxName = htlxName;
    }
    public Date getSqDate() {
        return sqDate;
    }

    public void setSqDate(Date sqDate) {
        this.sqDate = sqDate;
    }
    public String getHtCode() {
        return htCode;
    }

    public void setHtCode(String htCode) {
        this.htCode = htCode;
    }
    public String getHtName() {
        return htName;
    }

    public void setHtName(String htName) {
        this.htName = htName;
    }
    public BigDecimal getHtje() {
        return htje;
    }

    public void setHtje(BigDecimal htje) {
        this.htje = htje;
    }
    public Long getBabhId() {
        return babhId;
    }

    public void setBabhId(Long babhId) {
        this.babhId = babhId;
    }
    public String getBabhName() {
        return babhName;
    }

    public void setBabhName(String babhName) {
        this.babhName = babhName;
    }
    public Integer getHtfs() {
        return htfs;
    }

    public void setHtfs(Integer htfs) {
        this.htfs = htfs;
    }
    public Long getJbrId() {
        return jbrId;
    }

    public void setJbrId(Long jbrId) {
        this.jbrId = jbrId;
    }

    public String getJbrName() {
        return jbrName;
    }

    public void setJbrName(String jbrName) {
        this.jbrName = jbrName;
    }
    public String getJbrTel() {
        return jbrTel;
    }

    public void setJbrTel(String jbrTel) {
        this.jbrTel = jbrTel;
    }

    public String getSupplier() {
        return supplier;
    }

    public void setSupplier(String supplier) {
        this.supplier = supplier;
    }


    public String getSpTel() {
        return spTel;
    }

    public void setSpTel(String spTel) {
        this.spTel = spTel;
    }

    public String getSpUser() {
        return spUser;
    }

    public void setSpUser(String spUser) {
        this.spUser = spUser;
    }

    public String getRemark() {
        return remark;
    }

        public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getZkbmId() {
        return zkbmId;
    }

    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    public String getZkbmName() {
        return zkbmName;
    }

    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    public Integer getHtlb() {
        return htlb;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }
    public Integer getSignType() {
        return signType;
    }

    public void setHtlb(Integer htlb) {
        this.htlb = htlb;
    }
    public Long getHtId() {
        return htId;
    }

    public void setHtId(Long htId) {
        this.htId = htId;
    }

    public Long getAttachmentFileId() {
        return attachmentFileId;
    }

    public void setAttachmentFileId(Long attachmentFileId) {
        this.attachmentFileId = attachmentFileId;
    }
    public String getAttachmentFileName() {
        return attachmentFileName;
    }

    public void setAttachmentFileName(String attachmentFileName) {
        this.attachmentFileName = attachmentFileName;
    }
    public String getSignatureStatus() {
        return signatureStatus;
    }

    public void setSignatureStatus(String signatureStatus) {
        this.signatureStatus = signatureStatus;
    }
}

==> ejc-sealm-impl-3.0.0-20230923.074519-140-sources.jar: com/ejianc/business/sealm/bean/G9dzhtEntity.java <==
package com.ejianc.business.sealm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * G9历史工程电子合同
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_g9dzht")
public class G9dzhtEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="htlx_id")
    private Long htlxId; // 合同类型id
    @TableField(value="htlx_name")
    private String htlxName; // 合同类型名称
    @TableField(value="sq_date")
    private Date sqDate; // 申请日期
    @TableField(value="ht_code")
    private String htCode; // 合同编号
    @TableField(value="ht_name")
    private String htName; // 合同名称
    @TableField(value="htje")
    private BigDecimal htje; // 合同金额
    @TableField(value="babh_id")
    private Long babhId; // 备案编号id
    @TableField(value="babh_name")
    private String babhName; // 备案编号名称
    @TableField(value="htfs")
    private Integer htfs; // 合同份数（默认1）
    @TableField(value="jbr_id")
    private Long jbrId; // 经办人id
    @TableField(value="jbr_name")
    private String jbrName; // 经办人名称
    @TableField(value="jbr_tel")
    private String jbrTel; // 经办人联系方式
    @TableField(value="supplier")
    private String supplier; // 供方
    @TableField(value="sp_user")
    private String spUser; // 供方经办人
    @TableField(value="sp_tel")
    private String spTel; // 供方电话

    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="begin_date")
    private Date beginDate; // 开始日期
    @TableField(value="end_date")
    private Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称

    @TableField(value="sign_type")
    private Integer signType; // 0双方签署，1单方签署

    @TableField(value="htlb")
    private Integer htlb; // 合同类别 0正式，1补充协议
    @TableField(value="ht_id")
    private Long htId; // 合同编号id
    @TableField(value="attachment_file_id")
    private Long attachmentFileId; // 签章文件id
    @TableField(value="attachment_file_name")
    private String attachmentFileName; // 签章文件名称


    @TableField(value="signature_status")
    private String signatureStatus; // 签章状态（1表示已签章）
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别
    @TableField(value="signed_file_id")
    private Long signedFileId; // 签章完成文件
    @TableField(value="sqxm_id")
    private Long sqxmId; // 申请项目
    @TableField(value="sqxm_name")
    private String sqxmName; // 申请项目名称


    public Long getSqxmId() {
        return sqxmId;
    }

    public void setSqxmId(Long sqxmId) {
        this.sqxmId = sqxmId;
    }

    public String getSqxmName() {
        return sqxmName;
    }

    public void setSqxmName(String sqxmName) {
        this.sqxmName = sqxmName;
    }

    public Long getSignedFileId() {
        return signedFileId;
    }

    public void setSignedFileId(Long signedFileId) {
        this.signedFileId = signedFileId;
    }

    public Long getYzlbId() {
        return yzlbId;
    }

    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }

    public String getYzlbName() {
        return yzlbName;
    }

    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getHtlxId() {
        return htlxId;
    }

    public void setHtlxId(Long htlxId) {
        this.htlxId = htlxId;
    }
    public String getHtlxName() {
        return htlxName;
    }

    public void setHtlxName(String htlxName) {
        this.htlxName = htlxName;
    }
    public Date getSqDate() {
        return sqDate;
    }

    public void setSqDate(Date sqDate) {
        this.sqDate = sqDate;
    }
    public String getHtCode() {
        return htCode;
    }

    public void setHtCode(String htCode) {
        this.htCode = htCode;
    }
    public String getHtName() {
        return htName;
    }

    public void setHtName(String htName) {
        this.htName = htName;
    }
    public BigDecimal getHtje() {
        return htje;
    }

    public void setHtje(BigDecimal htje) {
        this.htje = htje;
    }
    public Long getBabhId() {
        return babhId;
    }

    public void setBabhId(Long babhId) {
        this.babhId = babhId;
    }
    public String getBabhName() {
        return babhName;
    }

    public void setBabhName(String babhName) {
        this.babhName = babhName;
    }
    public Integer getHtfs() {
        return htfs;
    }

    public void setHtfs(Integer htfs) {
        this.htfs = htfs;
    }
    public Long getJbrId() {
        return jbrId;
    }

    public void setJbrId(Long jbrId) {
        this.jbrId = jbrId;
    }

    public String getJbrName() {
        return jbrName;
    }

    public void setJbrName(String jbrName) {
        this.jbrName = jbrName;
    }
    public String getJbrTel() {
        return jbrTel;
    }

    public void setJbrTel(String jbrTel) {
        this.jbrTel = jbrTel;
    }

    public String getSupplier() {
        return supplier;
    }

    public void setSupplier(String supplier) {
        this.supplier = supplier;
    }


    public String getSpTel() {
        return spTel;
    }

    public void setSpTel(String spTel) {
        this.spTel = spTel;
    }

    public String getSpUser() {
        return spUser;
    }

    public void setSpUser(String spUser) {
        this.spUser = spUser;
    }

    public String getRemark() {
        return remark;
    }

        public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Date getBeginDate() {
        return beginDate;
    }

    public void setBeginDate(Date beginDate) {
        this.beginDate = beginDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Long getZkbmId() {
        return zkbmId;
    }

    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    public String getZkbmName() {
        return zkbmName;
    }

    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    public Integer getHtlb() {
        return htlb;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }
    public Integer getSignType() {
        return signType;
    }

    public void setHtlb(Integer htlb) {
        this.htlb = htlb;
    }
    public Long getHtId() {
        return htId;
    }

    public void setHtId(Long htId) {
        this.htId = htId;
    }

    public Long getAttachmentFileId() {
        return attachmentFileId;
    }

    public void setAttachmentFileId(Long attachmentFileId) {
        this.attachmentFileId = attachmentFileId;
    }
    public String getAttachmentFileName() {
        return attachmentFileName;
    }

    public void setAttachmentFileName(String attachmentFileName) {
        this.attachmentFileName = attachmentFileName;
    }
    public String getSignatureStatus() {
        return signatureStatus;
    }

    public void setSignatureStatus(String signatureStatus) {
        this.signatureStatus = signatureStatus;
    }
}
